@@ -8,7 +8,9 @@ from laipvt.helper.exception import UtilsError
 from laipvt.interface.serviceinterface import ServiceInterface
 from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.util import path_join, log, status_me
+from laipvt.sysutil.command import CREATE_DB
 from laipvt.sysutil.conf import AccountIdConfig
+from laipvt.model.sql import SqlModule
 
 
 class MageController(ServiceInterface):
@@ -137,9 +139,37 @@ class MageController(ServiceInterface):
             log.error("创建bucket失败")
             exit(2)
 
+    def create_mage_db_if_exist(self):
+        if self.middleware_cfg.mysql.is_deploy:
+            mysql_host = self.master_host.ipaddress
+        else:
+            mysql_host = self.middleware_cfg.mysql.ipaddress[0]
+        sql = SqlModule(host=mysql_host, port=int(self.middleware_cfg.mysql.port),
+                        user=self.middleware_cfg.mysql.username, passwd=self.middleware_cfg.mysql.password)
+        if not sql.select("show databases like '%_saas_docuds';"):
+            create_db = CREATE_DB.format(db_name="laiye_saas_docuds")
+            sql.insert_sql(create_db)
+
     @status_me("mage")
     def init_mage_mysql(self):
-        self.init_mysql(sql_path=self.service_path.sqls)
+        log.info("初始化mage mysql")
+        version = self.private_deploy_version.split("-")[0]
+
+        self.create_mage_db_if_exist()
+        cmd = "docker run --rm --entrypoint /home/works/program/mageTool \
+        {}/{}/document-mining-innerservice:{} --operateMode dbnew \
+        --host {} --user {} --password {} --port {} --toVersion {}".format(
+            self.registry_hub, self.project, self.private_deploy_version,
+            self.middleware_cfg.mysql.ipaddress[0], self.middleware_cfg.mysql.username, self.middleware_cfg.mysql.password, self.middleware_cfg.mysql.port,
+            version
+        )
+        res = self._exec_command_to_host(cmd=cmd, server=self.servers[0], check_res=True)
+        if res["code"] != 0:
+            log.error("初始化mage mysql失败")
+            log.error(res["stdout"])
+            exit(2)
+        log.info("初始化mage mysql完成")
+        #self.init_mysql(sql_path=self.service_path.sqls)
         # 渲染siber sqls目录
         # FileTemplate(self.middleware_cfg, self.service_path.siber_sqls, self.service_path.siber_sqls_ok).fill()
         # self.init_mysql(sql_path=self.service_path.siber_sqls_ok)
@@ -148,15 +178,27 @@ class MageController(ServiceInterface):
     def mage_transfer_data(self):
         src_dir_path = path_join(self.service_path.data, "mage_transfer_data")
         dest_dir_path = path_join(self.deploy_dir, "mage_transfer_data")
-        image = "{}/{}/document-mining-rpc:{}".format(self.registry_hub, self.project, self.private_deploy_version)
-
-        cmd = "docker run -v {dir_path}:/transfer_data --entrypoint /home/works/program/transferApp {image} \
-         --dataMode 2 --host {mysql_host} --port {mysql_port} --user {mysql_user} --password {mysql_password} \
-         --minioAddr http://{minio_host}:{minio_port} -dir /transfer_data".format(
-            dir_path=dest_dir_path, image=image,
-            mysql_host=self.master_host, minio_port=self.middleware_cfg.minio.port, mysql_port=self.middleware_cfg.mysql.port,
-            mysql_user=self.middleware_cfg.mysql.username, mysql_password=self.middleware_cfg.mysql.password,
-            minio_host=self.middleware_cfg.minio.lb
+        image = "{}/{}/document-mining-innerservice:{}".format(self.registry_hub, self.project, self.private_deploy_version)
+        version = self.private_deploy_version.split("-")[0]
+        # cmd = "docker run -v {dir_path}:/transfer_data --entrypoint /home/works/program/transferApp {image} \
+        #  --dataMode 2 --host {mysql_host} --port {mysql_port} --user {mysql_user} --password {mysql_password} \
+        #  --minioAddr http://{minio_host}:{minio_port} -dir /transfer_data".format(
+        #     dir_path=dest_dir_path, image=image,
+        #     mysql_host=self.middleware_cfg.mysql.ipaddress[0],
+        #     minio_port=self.middleware_cfg.minio.port,
+        #     mysql_port=self.middleware_cfg.mysql.port,
+        #     mysql_user=self.middleware_cfg.mysql.username,
+        #     mysql_password=self.middleware_cfg.mysql.password,
+        #     minio_host=self.middleware_cfg.minio.lb
+        # )
+        cmd = "docker run --rm --entrypoint /home/works/program/mageTool {image} \
+         --operateMode datatransfer --dataMode 2 --minioAddr http://{minio_host}:{minio_port} \
+          --host {mysql_host} --user {mysql_user} --password {mysql_password} --port {mysql_port} \
+          --toVersion {version}".format(
+            image=image, minio_host=self.middleware_cfg.minio.lb, minio_port=self.middleware_cfg.minio.port,
+            mysql_host=self.middleware_cfg.mysql.ipaddress[0],mysql_user=self.middleware_cfg.mysql.username,
+            mysql_password=self.middleware_cfg.mysql.password, mysql_port=self.middleware_cfg.mysql.port,
+            version=version
         )
         self._send_file(src=src_dir_path, dest=dest_dir_path)
         res = self._exec_command_to_host(cmd=cmd, server=self.servers[0], check_res=True)
@@ -176,10 +218,10 @@ class MageController(ServiceInterface):
         self.proxy_on_nginx(self.nginx_template, self.nginx_tmp, self.nginx_file_remote)
 
     def run(self):
+        self.push_mage_images()
         self.init_mage_mysql()
         self.init_identity_user()
         self.init_minio_data()
-        self.push_mage_images()
         self.deploy_configmap()
         self.mage_transfer_data()
         self.start_mage_service()
