@@ -18,12 +18,15 @@ class NlpController(ServiceInterface):
         self.bert_service_data_remote = path_join(self.deploy_dir, "bert-service-tf")
         self.poi_search_engine_src = path_join(self.data_dir, "laiye-poi-search-engine")
         self.poi_search_engine_remote = path_join(self.deploy_dir, "data", "laiye-poi-search-engine")
+        self.bert_service_pt_data_src = path_join(self.data_dir, "bert-service-pt")
+        self.bert_service_pt_data_remote = path_join(self.deploy_dir, "bert-service-pt")
 
     @status_me("nlp")
     def prepare_nlp(self):
         self._send_file(src=self.info_engine_data_src, dest=self.info_engine_data_remote)
         self._send_file(src=self.doc_classifer_data_src, dest=self.doc_classifer_data_remote)
         self._send_file(src=self.bert_service_data_src, dest=self.bert_service_data_remote)
+        self._send_file(src=self.bert_service_pt_data_src, dest=self.bert_service_pt_data_remote)
         self._send_file(src=self.poi_search_engine_src, dest=self.poi_search_engine_remote)
 
     @status_me("nlp")
