@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 from laipvt.handler.confighandler import CheckResultHandler
+from laipvt.handler.middlewarehandler import HarborConfigHandler
 from laipvt.sysutil.util import path_join
 
 
@@ -20,8 +21,10 @@ class KubeConfigHandler(object):
         self.apiserver_proxy_address = "127.0.0.1"
         self.lb_proxy_port = "6444"
         self.version = kwargs.get("version", "v1.18.12")
-        self.harbor_endpoint = "{}:{}".format(check_result.servers.get_role_ip("harbor")[0], 8888)
 
+        # self.harbor_endpoint = "{}:{}".format(check_result.servers.get_role_ip("harbor")[0], 8888)
+        self.harbor_cfg = HarborConfigHandler().get_config_with_check_result()
+        self.harbor_endpoint = "{}:{}".format(self.harbor_cfg["harbor"]["lb"], self.harbor_cfg["harbor"]["nginx_harbor_proxy_port"])
         self.image_repo = path_join(self.harbor_endpoint, "base_system")
         self.subnet = kwargs.get("subnet", "10.244.0.0/16")
 
