@@ -234,9 +234,10 @@ class KubeInterface:
                 cmd = TAINT_MASTER.format(node_name)
                 self._exec_command_to_host(cmd=cmd, server=self.master)
         elif len(node) > 0:
-            for server in self.result.servers.get_role_ip("node"):
-                cmd = self.get_kube_admin_join_command()
-                self._exec_command_to_host(cmd=cmd, server=server)
+            for server in self.result.servers.get_role_obj("node"):
+                if server.ipaddress in node:
+                    cmd = self.get_kube_admin_join_command()
+                    self._exec_command_to_host(cmd=cmd, server=server)
 
     def check_cluster_status(self) -> bool:
         kube = KubeModel()
