@@ -13,3 +13,6 @@ LAIPVT_LOG_PATH = "/usr/local/laipvt/logs"
 LAIPVT_LOG_NAME = "laipvt.log"
 LAIPVT_LOG_LEVEL = "DEBUG"
 LOG_TO_TTY = True
+
+# Certs
+CERTS_PATH = "/usr/local/laipvt/certs"
